@@ -1,10 +1,13 @@
 from protowhat.utils import _debug
+from protowhat.checks.check_simple import allow_errors
+from protowhat.checks.check_bash_history import has_command
 from protowhat.checks.check_files import check_file, has_dir
 from pythonwhat.checks.check_funcs import check_part, check_part_index, check_node
 from pythonwhat.checks.has_funcs import has_equal_part
-from pythonwhat.checks import check_object, check_logic, check_funcs, has_funcs
 from pythonwhat.checks.check_function import check_function
 from pythonwhat.checks.check_has_context import has_context
+from pythonwhat.checks import check_object, check_logic, check_funcs, has_funcs
+from pythonwhat.local import run
 
 from inspect import signature, Parameter
 from functools import partial, wraps
@@ -770,8 +773,16 @@ for k in ["check_object", "is_instance", "check_df", "check_keys"]:
 
 scts["has_context"] = has_context
 scts["check_function"] = check_function
+
+scts["run"] = run
+
+scts["has_command"] = has_command
+
 scts["check_file"] = check_file
 scts["has_dir"] = has_dir
+
+scts["allow_errors"] = allow_errors
+
 scts["_debug"] = _debug
 
 locals().update(scts)
